FolderAndFileService class

Constructors

FolderAndFileService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFile(String filePath, dynamic content, {bool showMessageWhenCreate = true}) Future
create file by specific path filePath and content content
createFolder(String folderPath) Future
create folder by specific path folderPath
readFile(String filePath, {bool createFileIfNotFound = true}) Future<String>
read file content by specific filePath